/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp;

import java.util.Properties;

import org.opensaml.xacml.ctx.RequestType;
import org.opensaml.xacml.ctx.ResponseType;

import eu.semiramis.policyManager.pdp.impl.ContextHandlerFactory;

/**
 * {@link ContextHandler} objects are used to handle XACML requests sent from
 * PEP and related responses
 * 
 */
public interface ContextHandler {

	public static final String CONTEXT_HANDLER_CLASS_PROPERTY = "contextHandler.class";

	/**
	 * Handle a XACML request providing the corresponding response.
	 * 
	 * @param request
	 *            the XACML request to handle
	 * 
	 * @return the corresponding XACML response
	 * @throws EvaluationException
	 *             if an exception occurs during request handling
	 * */
	public ResponseType handleRequest(RequestType request)
			throws EvaluationException;

	/**
	 * Set the current configuration properties in the handler.
	 * 
	 * @param properties
	 *            the new configuration properties
	 * @throws ConfigurationException
	 * 			  if the new configuration contains errors and cannot be applied
	 */
	public void setConfigurationProperties(Properties properties) throws ConfigurationException;
	
	/**
	 * Get the identifier of this Context Handler (to distinguish among PDP of different context handler instances). If Context Handlers are properly created, 
	 * by means of the <code>createContextHandler()</code> method in {@link ContextHandlerFactory} class, identifiers are guarantee to be unique in the current Java environment.
	 * 
	 * @return a {@link String} representation of the Context Handler identifier for this Context Handler instance
	 * 
	 * */
	public String getContextHandlerId();

}
