/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp;

import org.opensaml.xacml.ctx.RequestType;
import org.opensaml.xacml.ctx.ResponseType;

/**
 * Policy Decision Point (PDP) interface to evaluate XACML requests and get
 * corresponding XACML responses.
 * <p>
 * This interface is by the {@link ContextHandler} to evaluate XACML requests
 * sent by Policy Enforcement Points.
 * 
 */
public interface PDP {

	String getName();
	
	/**
	 * This method evaluates a XACML request against the set of policies defined
	 * for the PDP.
	 * 
	 * @param request
	 *            the XACML request to evaluate
	 * @return the XACML response
	 * 
	 * @throws EvaluationException
	 *             when the evaluation of the request fails for some reasons
	 * */
	ResponseType evaluate(RequestType request) throws EvaluationException;

	/**
	 * Tells the PDP that no more evaluations will be asked and the resources associated with the PDP can be released.
	 * 
	 */
	void destroy();

}
