/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp;

import java.util.Properties;

import org.opensaml.xacml.ctx.RequestType;

/**
 * Interface for {@link PDP} objects creators.
 * <p>
 * The actual class of the factory can be configured using the property name
 * {@link PDPFactory#PDP_FACTORY_CLASS_PROPERTY}.
 * 
 */
public interface PDPFactory {

	public static final String PDP_FACTORY_CLASS_PROPERTY = ".factory.class";
	
	/**
	 * Creates a new {@link PDP} basing on the custom configuration object
	 * provided, and the current request to be served.
	 * 
	 * @param configurationProperties
	 *            the custom configuration object
	 * @param request
	 *            the {@link RequestType} to be served
	 * @return the {@link PDP} to evaluate th request
	 * @throws ConfigurationException
	 *             if an exception occurs in getting the {@link PDP}
	 */
	public PDP getPDP(String pdpName, ContextHandler handler, Properties configurationProperties, RequestType request)
			throws ConfigurationException;

}
