/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp.an;

import org.slf4j.LoggerFactory;

import an.config.ConfigElement;
import an.log.Logger;

/**
 * This is a bridge class to export log messages from the {@link Logger}
 * framework to the SLF4J one.
 * 
 */
public class SLF4JLogger implements an.log.Logger {

	private org.slf4j.Logger logger;

	/**
	 * Constructor
	 */
	public SLF4JLogger(ConfigElement element, String tag) {

		if (tag == null) {
			tag = org.slf4j.Logger.ROOT_LOGGER_NAME;
		}

		this.logger = LoggerFactory.getLogger(tag);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#info(java.lang.Object)
	 */
	@Override
	public void info(Object message) {
		logger.info(message.toString());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#info(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void info(Object message, Throwable t) {
		logger.info(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#warn(java.lang.Object)
	 */
	@Override
	public void warn(Object message) {
		logger.warn(message.toString());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#warn(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void warn(Object message, Throwable t) {
		logger.warn(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#error(java.lang.Object)
	 */
	@Override
	public void error(Object message) {
		logger.error(message.toString());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#error(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void error(Object message, Throwable t) {
		logger.error(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#fatal(java.lang.Object)
	 */
	@Override
	public void fatal(Object message) {
		logger.error(message.toString());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#fatal(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void fatal(Object message, Throwable t) {
		logger.error(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#trace(java.lang.Object)
	 */
	@Override
	public void trace(Object message) {
		logger.trace(message.toString());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#trace(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void trace(Object message, Throwable t) {
		logger.trace(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#debug(java.lang.Object)
	 */
	@Override
	public void debug(Object message) {
		logger.debug(message.toString());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#debug(java.lang.Object, java.lang.Throwable)
	 */
	@Override
	public void debug(Object message, Throwable t) {
		logger.debug(message.toString(), t);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#getTag()
	 */
	@Override
	public String getTag() {
		return logger.getName();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see an.log.Logger#isDebugEnabled()
	 */
	@Override
	public boolean isDebugEnabled() {
		return logger.isDebugEnabled();
	}

}
