/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.StringTokenizer;

import org.opensaml.xacml.ctx.DecisionType;
import org.opensaml.xacml.ctx.RequestType;
import org.opensaml.xacml.ctx.ResponseType;
import org.opensaml.xml.io.MarshallingException;
import org.opensaml.xml.util.XMLHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import eu.semiramis.policyManager.pdp.ConfigurationException;
import eu.semiramis.policyManager.pdp.ContextHandler;
import eu.semiramis.policyManager.pdp.EvaluationException;
import eu.semiramis.policyManager.pdp.PDP;
import eu.semiramis.policyManager.pdp.PDPFactory;
import eu.semiramis.policyManager.pdp.impl.AbstractContextHandler;
import eu.semiramis.policyManager.util.PMUtils;
import eu.semiramis.policyManager.util.opensaml.XACMLUtils;

/**
 * Base implementation of the {@link ContextHandler} interface
 * 
 */
public class MultiplePdpContextHandlerImpl extends AbstractContextHandler {

	final Logger logger = LoggerFactory
			.getLogger(MultiplePdpContextHandlerImpl.class);


	@Override
	ResponseType handle(RequestType request) throws EvaluationException {
		
		// get pdp names
		String pdpNamesProperty = properties.getProperty("pdp.names");
		StringTokenizer pdpNames = new StringTokenizer(pdpNamesProperty, ",");
		
		boolean decisionMade=false;
		ResponseType response =null;
		// iterate on pdps (while decision not made)
		while (pdpNames.hasMoreElements() && (!decisionMade)) {
			String pdpName=pdpNames.nextToken();
			// get pdp world
			String worldType=properties.getProperty(pdpName+".world");
			
			// handle request by pdp
			//ResponseType response = handleByPdp(pdpName, request);
			response = handleByPdp(pdpName, request);
			DecisionType decision = response.getResult().getDecision();
			logger.info("Processing {} with type {}",pdpName,worldType);
			logger.info("Partial decision made {}",decision.getDecision());
			
			// check response 
			// if response is Deny or (NA on CW) (deny on CW is a no-sense)
				// return deny
			
			if ((decision.getDecision()==DecisionType.DECISION.Deny) || ((decision.getDecision()==DecisionType.DECISION.NotApplicable) && (worldType.equalsIgnoreCase("close")))) {
				logger.info("Final decision made {}",decision.getDecision());
				response.getResult().getDecision().setDecision(DecisionType.DECISION.Deny);
				return response;	
			}
		}
		
		// return permit
		 
		response.getResult().getDecision().setDecision(DecisionType.DECISION.Permit);
		
		logger.info("Final decision made {}",response.getResult().getDecision());
		
		
		return response;
	}


	@Override
	Logger getLogger() {
		return logger;
	}

}
