/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp.jboss;

import java.util.Properties;

import org.jboss.security.xacml.interfaces.PolicyLocator;

import eu.semiramis.policyManager.pdp.ConfigurationException;

/**
 * Interface for {@link PolicyLocator} factories.
 * 
 */
public interface LocatorFactory {

	public static final String JBOSS_LOCATOR_FACTORY_CLASS_PROPERTY = ".factory.jboss.locatorFactory.class";

	/**
	 * Gets a {@link PolicyLocator} to locate policies for XACML request
	 * evaluation.
	 * 
	 * @param properties
	 *            the {@link Properties} to configure the {@link PolicyLocator}
	 * @return the {@link PolicyLocator} to use to locate policies
	 * @throws ConfigurationException
	 *             if the retrieve of the {@link PolicyLocator} fails
	 */
	PolicyLocator getLocator(Properties properties)
			throws ConfigurationException;
}
