/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp.jboss.locators;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import org.jboss.security.xacml.core.JBossXACMLPolicy;
import org.jboss.security.xacml.interfaces.XACMLPolicy;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import eu.semiramis.policyManager.pdp.ConfigurationException;

/**
 * This locator loads policySets from a local directory at creation time.
 * Policies are not reloaded dynamically when changed.
 * 
 */
public class StaticDirectoryLocator extends
		org.jboss.security.xacml.locators.JBossPolicySetLocator {

	final Logger logger = LoggerFactory
			.getLogger(StaticDirectoryLocatorFactory.class);

	private String dirName;

	public StaticDirectoryLocator(String directoryName)
			throws ConfigurationException {
		super();

		this.dirName = directoryName;

		if (dirName == null) {
			throw new NullPointerException(
					"The policySet directory cannot be null");
		}

		// create policy set
		Set<XACMLPolicy> policies = new HashSet<XACMLPolicy>();

		// create directory object
		File directory = new File(dirName);
		if (!directory.isDirectory()) {
			throw new IllegalArgumentException("The path " + dirName
					+ " is not a directory");
		}

		// iterate on the fileset
		for (File policyFile : directory.listFiles()) {
			try {

				JBossXACMLPolicy policySet = new JBossXACMLPolicy(policyFile
						.toURI().toURL(), XACMLPolicy.POLICYSET);

				logger.info("loaded policyset from file {}: \n{}",
						policyFile.getAbsolutePath(), policySet);

				policies.add(policySet);

			} catch (Exception e) {

				logger.error("cannot read policyset from file {}",
						policyFile.getAbsolutePath());

				// continue with other files
			}
		}

		// set policies in the locator
		setPolicies(policies);
	}

}
