/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.pdp.jboss.locators;

import java.util.Properties;

import org.jboss.security.xacml.interfaces.PolicyLocator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import eu.semiramis.policyManager.pdp.ConfigurationException;
import eu.semiramis.policyManager.pdp.jboss.LocatorFactory;

/**
 * Concrete implementation of the {@link LocatorFactory} that creates
 * {@link StaticDirectoryLocator} objects.
 * 
 */
public class StaticDirectoryLocatorFactory implements LocatorFactory {

	public static final String JBOSS_POLICYSET_DIR_PROPERTY = "pdp.factory.jboss.policySet.dir";

	final static Logger logger = LoggerFactory
			.getLogger(StaticDirectoryLocatorFactory.class);

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.semiramis.policyManager.pdp.jboss.LocatorFactory#getLocator(java.util
	 * .Properties)
	 */
	@Override
	public PolicyLocator getLocator(Properties properties)
			throws ConfigurationException {

		String directory = properties
				.getProperty(StaticDirectoryLocatorFactory.JBOSS_POLICYSET_DIR_PROPERTY);

		logger.info("creating new StaticDirectoryLocator for directory {}",
				directory);

		StaticDirectoryLocator locator;
		try {
			locator = new StaticDirectoryLocator(directory);
		} catch (Exception e) {
			throw new ConfigurationException(
					"Cannot create the StaticDirectoryLocator for directory "
							+ directory, e);
		}

		return locator;
	}

}
