/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.samples;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Iterator;
import java.util.Properties;

import org.opensaml.DefaultBootstrap;
import org.opensaml.xacml.ctx.DecisionType;
import org.opensaml.xacml.ctx.RequestType;
import org.opensaml.xacml.ctx.ResponseType;
import org.opensaml.xacml.policy.ObligationType;
import org.opensaml.xacml.policy.ObligationsType;
import org.opensaml.xml.parse.BasicParserPool;
import org.w3c.dom.Document;

import eu.semiramis.policyManager.pdp.ContextHandler;
import eu.semiramis.policyManager.pdp.PDPFactory;
import eu.semiramis.policyManager.pdp.impl.ContextHandlerFactory;
import eu.semiramis.policyManager.pdp.jboss.LocatorFactory;
import eu.semiramis.policyManager.pdp.jboss.locators.StaticDirectoryLocatorFactory;
import eu.semiramis.policyManager.util.opensaml.XACMLUtils;

/**
 * Base implementation for a Policy Enforcement Point.
 * <p>
 * Shows the code to create a {@link ContextHandler} and submit a XACML request.
 * 
 */
public class PEPSample {

	public static void main(String[] args) throws Exception {

		// Initialize OpenSAML
		DefaultBootstrap.bootstrap();

		// Three options to instantiate the ContextHandler:

		// 1) create a new ContextHandler basing on the default configuration
		// file
		ContextHandler handler = ContextHandlerFactory.createContextHandler();

		// 2) create a new ContextHandler using a custom configuration file
		//ContextHandler handler2 = ContextHandlerFactory
		//		.createContextHandler("contextHandler.properties");
/*
		// 3) create a new ContextHandler using a custom Properties
		// object
		Properties properties = new Properties();

		// ...populate the ConfigurationProperties object...
		properties
				.setProperty(ContextHandler.CONTEXT_HANDLER_CLASS_PROPERTY,
						"eu.semiramis.policyManager.pdp.impl.DefaultContextHandlerImpl");
		properties.setProperty(PDPFactory.PDP_FACTORY_CLASS_PROPERTY,
				"eu.semiramis.policyManager.pdp.jboss.JBossPDPFactory");
		properties
				.setProperty(
						LocatorFactory.JBOSS_LOCATOR_FACTORY_CLASS_PROPERTY,
						"eu.semiramis.policyManager.pdp.jboss.locators.StaticDirectoryLocatorFactory");
		properties.setProperty(
				StaticDirectoryLocatorFactory.JBOSS_POLICYSET_DIR_PROPERTY,
				"policySamples");

		ContextHandler handler3 = ContextHandlerFactory
				.createContextHandler(properties);
*/
		// read request from file
		BasicParserPool parser = new BasicParserPool();
		parser.setNamespaceAware(true);

		// Parse file
		//InputStream in = new FileInputStream("./requestSamples/SampleRequest.xml");
		InputStream in = new FileInputStream("./requestSamples/SampleRequestForPolicyModel.xml");
		Document doc = parser.parse(in);

		// Unmarshall using the document root element
		RequestType request = XACMLUtils.unmarshall(doc);

		ResponseType response = handler.handleRequest(request);
		//ResponseType response = handler2.handleRequest(request);
		
		
		DecisionType decision = response.getResult().getDecision();
		System.out.println("decision: "+decision.getDecision());
		if (decision.getDecision() == DecisionType.DECISION.Permit){
			// add behaviour
		}
		else {
			// add behaviour
		}
		
		

	}

}
