/**
 *    Copyright (C) 2012, 2013 Engineering Ingeneria Informatica s.p.a.
 *
 *    Authors:
 *     Paolo Roccetti <paolo.roccetti@eng.it>
 *     Silvio Sorace <silvio.sorace@eng.it>
 *
 *    This file is part of SEMIRAMIS Policy Management library (PM).
 *
 *    PM is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU Lesser General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    PM is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public License
 *    along with PM. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package eu.semiramis.policyManager.util.opensaml;

import java.io.InputStream;

import org.opensaml.Configuration;
import org.opensaml.xacml.ctx.ResponseType;
import org.opensaml.xml.io.Unmarshaller;
import org.opensaml.xml.io.UnmarshallingException;
import org.opensaml.xml.parse.BasicParserPool;
import org.opensaml.xml.parse.XMLParserException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * 
 * Utility methods to deal with openSAML XACML Responses
 * 
 */
public class XACMLResponseUtils {

	/**
	 * Deserialize a XACML response from a stream
	 * 
	 * @param responseStream
	 *            the stream containing the XACML response
	 * @throws XMLParserException
	 *             if an exception occurs during parsing
	 * @throws UnmarshallingException
	 *             if an exception occus during unmarshalling
	 * */
	public static ResponseType deserialize(InputStream responseStream)
			throws XMLParserException, UnmarshallingException {

		// Get parser pool manager
		BasicParserPool parser = new BasicParserPool();
		parser.setNamespaceAware(true);

		// Parse byte array
		Document responseDocument = parser.parse(responseStream);
		Element responseElement = responseDocument.getDocumentElement();

		// get the openSAML unmarshaller for the response element
		Unmarshaller unmarshaller = Configuration.getUnmarshallerFactory()
				.getUnmarshaller(ResponseType.DEFAULT_ELEMENT_NAME);

		// unmarshall the response
		ResponseType openSAMLResponse = (ResponseType) unmarshaller
				.unmarshall(responseElement);

		return openSAMLResponse;
	}
}
